@@ -38,7 +38,7 @@ from akangatu.transf.config import safety
 from garoupa.encoders import integers2bytes, bytes2integers
 
 
-###@lru_cache()
+@lru_cache()
 def compression_dict():  # TODO: update dictionary
     txt_comming_from_a_file_for_training_of_compressor = "aasfdkjgd kajgsdf af kajgakjsg fkajgs df\n" * 653
     samples = [
@@ -47,6 +47,7 @@ def compression_dict():  # TODO: update dictionary
     ]
     return zs.train_dictionary(dict_size=99999999, samples=samples, threads=-1)
 
+
 # ##################################################
 
 class HashableBinary:
@@ -67,70 +68,69 @@ def memopack(hashable_binary):
     return pack(hashable_binary.obj)
 
 
-#compression_lock = new_lock()
+# compression_lock = new_lock()
 
 
 def pack(obj):
+    cctx = zs.ZstdCompressor(threads=-1)
+    cctxdic = zs.ZstdCompressor(threads=-1, dict_data=compression_dict(), write_dict_id=False)
 
-        cctx = zs.ZstdCompressor(threads=-1)
-        cctxdic = zs.ZstdCompressor(threads=-1, dict_data=compression_dict(), write_dict_id=False)
-
-        cctxdec = zs.ZstdDecompressor()
-        cctxdicdec = zs.ZstdDecompressor(dict_data=compression_dict())
+    cctxdec = zs.ZstdDecompressor()
+    cctxdicdec = zs.ZstdDecompressor(dict_data=compression_dict())
 
     # with safety():
-        if isinstance(obj, np.ndarray) and str(obj.dtype) == "float64" and len(obj.shape) == 2:
-            # X, ...
-            h, w = obj.shape
-            fast_reduced = lz.compress(obj.reshape(w * h), compression_level=1)
-            header = integers2bytes(obj.shape)
-            return b"F" + header + cctx.compress(fast_reduced)
-        elif isinstance(obj, (list, set, str, int, float, bytearray, bool)):
-            # steps, ...
-            js = json.dumps(obj, sort_keys=True, ensure_ascii=False)
-            return b"J" + cctx.compress(js.encode())
-        elif isinstance(obj, str):
-            return b"T" + cctxdic.compress(obj.encode())  # b'T'+0s==1409286144
-        elif isinstance(obj, bytes):
-            fast_reduced = lz.compress(obj, compression_level=1)
-            return b"B" + cctx.compress(fast_reduced)
-        elif callable(obj):
-            raise Exception("Cannot compress callable", type(obj))
-        else:
-            # print(f"Unknown type {type(obj)}{'-' + str(obj.dtype) if 'ndarray' in str(type(obj)) else ''} to compress, using pickle...")
-            # categorical ndarrays, ...
-            pickled = pickle.dumps(obj)  # 1169_airlines explodes here with RAM < ?
-            fast_reduced = lz.compress(pickled, compression_level=1)
-            return b"P" + cctx.compress(fast_reduced)  # b'P'+0s==1342177280
+    if isinstance(obj, np.ndarray) and str(obj.dtype) == "float64" and len(obj.shape) == 2:
+        # X, ...
+        h, w = obj.shape
+        fast_reduced = lz.compress(obj.reshape(w * h), compression_level=1)
+        header = integers2bytes(obj.shape)
+        return b"F" + header + cctx.compress(fast_reduced)
+    elif isinstance(obj, (list, set, str, int, float, bytearray, bool)):
+        # steps, ...
+        js = json.dumps(obj, sort_keys=True, ensure_ascii=False)
+        return b"J" + cctx.compress(js.encode())
+    elif isinstance(obj, str):
+        return b"T" + cctxdic.compress(obj.encode())  # b'T'+0s==1409286144
+    elif isinstance(obj, bytes):
+        fast_reduced = lz.compress(obj, compression_level=1)
+        return b"B" + cctx.compress(fast_reduced)
+    elif callable(obj):
+        raise Exception("Cannot compress callable", type(obj))
+    else:
+        # print(f"Unknown type {type(obj)}{'-' + str(obj.dtype) if 'ndarray' in str(type(obj)) else ''} to compress, using pickle...")
+        # categorical ndarrays, ...
+        pickled = pickle.dumps(obj)  # 1169_airlines explodes here with RAM < ?
+        fast_reduced = lz.compress(pickled, compression_level=1)
+        return b"P" + cctx.compress(fast_reduced)  # b'P'+0s==1342177280
 
 
 def unpack(dump_with_header):
-        cctx = zs.ZstdCompressor(threads=-1)
-        cctxdic = zs.ZstdCompressor(threads=-1, dict_data=compression_dict(), write_dict_id=False)
+    cctx = zs.ZstdCompressor(threads=-1)
+    cctxdic = zs.ZstdCompressor(threads=-1, dict_data=compression_dict(), write_dict_id=False)
 
-        cctxdec = zs.ZstdDecompressor()
-        cctxdicdec = zs.ZstdDecompressor(dict_data=compression_dict())
+    cctxdec = zs.ZstdDecompressor()
+    cctxdicdec = zs.ZstdDecompressor(dict_data=compression_dict())
 
     # with safety():
-        header = dump_with_header[:1]
-        dump = dump_with_header[1:]
-        if header == b"P":
-            decompressed = lz.decompress(cctxdec.decompress(dump))
-            return pickle.loads(decompressed)
-        elif header == b"T":
-            return cctxdicdec.decompress(dump).decode()
-        elif header == b"B":
-            return lz.decompress(cctxdec.decompress(dump))
-        elif header == b"F":
-            header = dump_with_header[1:9]
-            dump = dump_with_header[9:]
-            decompressed = lz.decompress(cctxdec.decompress(dump))
-            [h, w] = bytes2integers(header)
-            return np.reshape(np.frombuffer(decompressed), newshape=(h, w))
-        elif header == b"J":
-            return json.loads(cctxdec.decompress(dump).decode())
-        else:
-            raise Exception("Unknown compression format:", header, dump[:300])
+    header = dump_with_header[:1]
+    dump = dump_with_header[1:]
+    if header == b"P":
+        decompressed = lz.decompress(cctxdec.decompress(dump))
+        return pickle.loads(decompressed)
+    elif header == b"T":
+        return cctxdicdec.decompress(dump).decode()
+    elif header == b"B":
+        return lz.decompress(cctxdec.decompress(dump))
+    elif header == b"F":
+        header = dump_with_header[1:9]
+        dump = dump_with_header[9:]
+        decompressed = lz.decompress(cctxdec.decompress(dump))
+        [h, w] = bytes2integers(header)
+        return np.reshape(np.frombuffer(decompressed), newshape=(h, w))
+    elif header == b"J":
+        return json.loads(cctxdec.decompress(dump).decode())
+    else:
+        raise Exception("Unknown compression format:", header, dump[:300])
 
 # def pack_object(obj):  #blosc is buggy
 #     """
